==> qtwebengine-everywhere-src-5.12.0.tar.xz: qtwebengine-everywhere-src-5.12.0/src/core/service/service_qt.h <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtWebEngine module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef SERVICE_QT_H
#define SERVICE_QT_H

#include "base/no_destructor.h"
#include "services/service_manager/embedder/embedded_service_info.h"

namespace service_manager {
class Connector;
class Service;
}  // namespace service_manager

class ServiceQt {
public:
    static ServiceQt *GetInstance();

    void InitConnector();
    service_manager::EmbeddedServiceInfo::ServiceFactory CreateServiceQtFactory();
    service_manager::Connector *connector() { return m_connector.get(); }

private:
    friend class base::NoDestructor<ServiceQt>;
    class IOThreadContext;

    ServiceQt();
    ~ServiceQt();

    std::unique_ptr<service_manager::Service> CreateServiceQtWrapper();

    const std::unique_ptr<IOThreadContext> m_ioThreadContext;

    std::unique_ptr<service_manager::Connector> m_connector;

    DISALLOW_COPY_AND_ASSIGN(ServiceQt);
};

#endif // SERVICE_QT_H

==> qtwebengine-everywhere-src-5.13.0.tar.xz: qtwebengine-everywhere-src-5.13.0/src/core/service/service_qt.h <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtWebEngine module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef SERVICE_QT_H
#define SERVICE_QT_H

#include "base/no_destructor.h"
#include "content/public/common/service_manager_connection.h"

namespace service_manager {
class Connector;
class Service;
}  // namespace service_manager

class ServiceQt {
public:
    static ServiceQt *GetInstance();

    void InitConnector();
    content::ServiceManagerConnection::ServiceRequestHandler CreateServiceQtRequestHandler();
    service_manager::Connector *connector() { return m_connector.get(); }

private:
    friend class base::NoDestructor<ServiceQt>;
    class IOThreadContext;

    ServiceQt();
    ~ServiceQt();

    void BindServiceQtRequest(service_manager::mojom::ServiceRequest request);

    const std::unique_ptr<IOThreadContext> m_ioThreadContext;

    std::unique_ptr<service_manager::Connector> m_connector;

    DISALLOW_COPY_AND_ASSIGN(ServiceQt);
};

#endif // SERVICE_QT_H
